@@ -13,7 +13,7 @@ use 5.010;
 use warnings;
 use strict;
 
-our $VERSION = '0.9';
+our $VERSION = '0.91';
 
 =head1 NAME
 
@@ -54,11 +54,18 @@ To install this extension, run the following commands:
 Executing the last command creates 2 new custom fields, so please do it only
 once. These fields contain the i-doit mandator and the referenced objects.
 
+Another way to install the latest release is via CPAN:
+
+    cpan RT::Extension::ReferenceIDoitObjects
+    $RT_HOME/sbin/rt-setup-database --action insert --datafile /opt/rt4/local/plugins/RT-Extension-ReferenceIDoitObjects/etc/initialdata
+
+The second command is equivalent to C<make initdb>, but is unfortunately not executed automatically. C<$RT_HOME> is the path to your RT installation, for example C</opt/rt4>.
+
 
 =head1 CONFIGURATION
 
 To enable this extension edit the RT site configuration based in
-C<RT_HOME/etc/RT_SiteConfig.pm>:
+C<$RT_HOME/etc/RT_SiteConfig.pm>:
 
     Set(@Plugins,qw(RT::Extension::ReferenceIDoitObjects));
 
@@ -118,7 +125,8 @@ The user's password is encoded as a MD5 hash.
 
 You need the identifier of a mandator who owns the objects, but this may also be
 set while creating a ticket. This identifier has be to added to the list of the
-corresponding custom field.
+corresponding custom field. For a list of (activated) mandators and their
+identifiers see i-doit's admin center.
 
 
 =item C<$IDoitDefaultView>
@@ -169,6 +177,14 @@ This is an example for deleting the mason cache and restarting the Apache HTTP
 web server on a Debian GNU/Linux based operating system.
 
 
+=head1 USAGE
+
+Whenever you create a new ticket or edit an existing one you are able to
+reference this ticket with one or more objects in i-doit. An additional box
+with the so-called "object browser" will shown up. Just select the objects you
+need or unselect the objects you don't need.
+
+
 =head1 AUTHORS
 
 Benjamin Heisig, E<lt>bheisig@synetics.deE<gt>
